@@ -85,11 +85,11 @@
 #' @param weightVar = If provided, a vector objective will be used to weight the data. (default = NULL).
 #' @param equateMeans Whether to equate the means across twins (defaults to TRUE).
 #' @param bVector Whether to compute row-wise likelihoods (defaults to FALSE).
-#' @param covMethod How to treat covariates: "fixed" (default) or "random".
 #' @param autoRun Whether to run the model (default), or just to create it and return without running.
 #' @param tryHard Default ('no') uses normal mxRun. "yes" uses mxTryHard. Other options: "ordinal", "search"
 #' @param optimizer Optionally set the optimizer (default NULL does nothing).
-#' @return - [mxModel()] subclass `mxModel.ACE`
+#' @param nSib Number of sibs, default is 2. Working on 3 :-)
+#' @return - [mxModel()] subclass `mxModelACEv`
 #' @export
 #' @family Twin Modeling Functions
 #' @references - Verhulst, B., Prom-Wormley, E., Keller, M., Medland, S., & Neale, M. C. (2019).
@@ -143,20 +143,24 @@
 #' #    but scaling is advisable.
 #' # 
 #' require(umx)
+#' # Load data and rescale height to cm (var in m too small)
 #' data(twinData) # ?twinData from Australian twins.
-#' # height var is very small: move from m to cm to increase.
 #' twinData[,c("ht1", "ht2")]= twinData[,c("ht1", "ht2")]*100
-#' mzData <- twinData[twinData$zygosity %in% "MZFF", ]
-#' dzData <- twinData[twinData$zygosity %in% "DZFF", ]
+#'
+#' mzData = twinData[twinData$zygosity %in% "MZFF", ]
+#' dzData = twinData[twinData$zygosity %in% "DZFF", ]
 #' m1 = umxACEv(selDVs = "ht", sep = "", dzData = dzData, mzData = mzData)
+#' 
 #' umxSummary(m1, std = FALSE) # unstandardized
-#' # tip: with report = "html", umxSummary can print the table to your browser!
 #' plot(m1)
+#'
+#' # tip: with report = "html", umxSummary can print the table to your browser!
+#' # tip: You can turn off auto-plot with umx_set_auto_plot(FALSE)
 #' 
 #' # ========================================================
 #' # = Evidence for dominance ? (DZ correlation set to .25) =
 #' # ========================================================
-#' m2 = umxACEv("ADE", selDVs = "ht", sep="", dzData = dzData, mzData = mzData, dzCr = .25)
+#' m2 = umxACEv("ADE", selDVs = "ht", dzCr = .25, sep="", dzData = dzData, mzData = mzData)
 #' umxCompare(m2, m1) # Is ADE better?
 #' umxSummary(m2, comparison = m1) # nb: though this is ADE, matrices are still called A,C,E
 #'
@@ -251,17 +255,13 @@
 #' m1 = umxACEv(selDVs = selDVs, sep= "", dzData = dz, mzData= mz, numObsDZ= 569, numObsMZ= 351)
 #' umxSummary(m1, std = FALSE)
 #' 
-umxACEv <- function(name = "ACEv", selDVs, selCovs = NULL, sep = NULL, dzData, mzData, dzAr = .5, dzCr = 1, type = c("Auto", "FIML", "cov", "cor", "WLS", "DWLS", "ULS"), allContinuousMethod = c("cumulants", "marginals"),
-	data = NULL, zyg = "zygosity", weightVar = NULL, numObsDZ = NULL, numObsMZ = NULL, addStd = TRUE, addCI = TRUE, 
-	boundDiag = NULL, equateMeans = TRUE, bVector = FALSE,  covMethod = c("fixed", "random"), 
-	autoRun = getOption("umx_auto_run"), tryHard = c("no", "yes", "ordinal", "search"), optimizer = NULL) {
-	nSib                = 2 # number of siblings in a twin pair
+umxACEv <- function(name = "ACEv", selDVs, selCovs = NULL, sep = NULL, dzData, mzData, dzAr = .5, dzCr = 1, type = c("Auto", "FIML", "cov", "cor", "WLS", "DWLS", "ULS"), allContinuousMethod = c("cumulants", "marginals"), data = NULL, zyg = "zygosity", weightVar = NULL, numObsDZ = NULL, numObsMZ = NULL, addStd = TRUE, addCI = TRUE, boundDiag = NULL, equateMeans = TRUE, bVector = FALSE, autoRun = getOption("umx_auto_run"), tryHard = c("no", "yes", "ordinal", "search"), optimizer = NULL, nSib = 2) {
 	type                = match.arg(type)
-	covMethod           = match.arg(covMethod)
 	allContinuousMethod = match.arg(allContinuousMethod)
 	if(dzCr == .25 & name == "ACEv"){ name = "ADEv" }
+	if(nSib != 2){umx_msg(paste0("I can only handle 2 sibs, you gave me ", nSib)) }
 
-	# if data provided create twin files 
+	# If data provided create twin files 
 	if(!is.null(data)){
 		if(is.null(sep)){ sep = "_T" }
 		# avoid ingesting tibbles
@@ -271,8 +271,6 @@ umxACEv <- function(name = "ACEv", selDVs, selCovs = NULL, sep = NULL, dzData, m
 		if(is.null(dzData)){ dzData = "DZ"; mzData = "MZ" }
 		mzData = data[data[,zyg] %in% mzData, ]
 		dzData = data[data[,zyg] %in% dzData, ]
-		# mzData = data[data[,zyg] %in% ifelse(is.null(mzData), "DZ", mzData), ]
-		# dzData = data[data[,zyg] %in% ifelse(is.null(dzData), "DZ", dzData), ]
 	}else{
 		# avoid ingesting tibbles
 		if("tbl" %in% class(mzData)){
@@ -283,21 +281,30 @@ umxACEv <- function(name = "ACEv", selDVs, selCovs = NULL, sep = NULL, dzData, m
 
 	xmu_twin_check(selDVs= selDVs, sep = sep, dzData = dzData, mzData = mzData, enforceSep = TRUE, nSib = nSib, optimizer = optimizer)
 	
-	# If given covariates, call umxACEvcov
-	if(covMethod == "random") {
-		stop("random covariates for umxACEv not yet implemented")
-		# TODO implement umxACEvcov or refactor
-		# TODO add allContinuousMethod = allContinuousMethod and type
-		# umxACEvcov(name = name, selDVs=selDVs, selCovs=selCovs, dzData=dzData, mzData=mzData, sep = sep, dzAr = dzAr, dzCr = dzCr, addStd = addStd, addCI = addCI, boundDiag = boundDiag, equateMeans = equateMeans, bVector = bVector, autoRun = autoRun, tryHard = tryHard)
-	}
-	# nSib = 2, equateMeans = TRUE, verbose = verbose
 	selVars = tvars(selDVs, sep = sep, suffixes= 1:nSib)
-	nVar = length(selVars)/nSib; # Number of dependent variables ** per INDIVIDUAL ( so times-2 for a family) **
+	nVar    = length(selVars)/nSib; # Number of dependent variables ** per INDIVIDUAL ( so times-2 for a family) **
 	
 	model = xmu_make_TwinSuperModel(name=name, mzData = mzData, dzData = dzData, selDVs = selDVs, selCovs= selCovs, sep = sep, type = type, allContinuousMethod = allContinuousMethod, numObsMZ = numObsMZ, numObsDZ = numObsDZ, nSib= nSib, equateMeans = equateMeans, weightVar = weightVar)
-	tmp = xmu_starts(mzData, dzData, selVars = selDVs, sep = sep, nSib = nSib, varForm = "Cholesky", equateMeans= equateMeans, SD= TRUE, divideBy = 3)
+	tmp   = xmu_starts(mzData, dzData, selVars = selDVs, sep = sep, nSib = nSib, varForm = "Cholesky", equateMeans= equateMeans, SD= TRUE, divideBy = 3)
 
 	# Finish building top
+	if(nSib==2){
+		expCovMZ = mxAlgebra(rbind (cbind(ACE,  AC), cbind( AC, ACE)), dimnames = list(selVars, selVars), name = "expCovMZ")
+		expCovDZ = mxAlgebra(rbind (cbind(ACE, hAC), cbind(hAC, ACE)), dimnames = list(selVars, selVars), name = "expCovDZ")
+	} else if (nSib==3) {
+		expCovMZ = mxAlgebra(name="expCovMZ", dimnames = list(selVars, selVars), rbind(
+			cbind(ACE,  AC, hAC),
+		    cbind(AC , ACE, hAC),
+		    cbind(hAC, hAC, ACE))
+		)
+		expCovDZ = mxAlgebra(name= "expCovDZ", dimnames = list(selVars, selVars), rbind(
+			cbind(ACE, hAC, hAC),
+			cbind(hAC, ACE, hAC),
+			cbind(hAC, hAC, ACE))
+		)
+	}else{
+		stop("3 sibs is experimental, but ", nSib, "? ... Maybe come back in 2022, best tim :-)")
+	}
 	top = mxModel(model$top,
 		# "top" defines the algebra of the twin model, which MZ and DZ slave off of
 		# NB: top already has the means model and thresholds matrix added if necessary  - see above
@@ -312,10 +319,7 @@ umxACEv <- function(name = "ACEv", selDVs, selCovs = NULL, sep = NULL, dzData, m
 		mxAlgebra(name = "ACE", A+C+E),
 		mxAlgebra(name = "AC" , A+C  ),
 		mxAlgebra(name = "hAC", (dzAr %x% A) + (dzCr %x% C)),
-		mxAlgebra(rbind (cbind(ACE, AC),
-		                 cbind(AC , ACE)), dimnames = list(selVars, selVars), name = "expCovMZ"),
-		mxAlgebra(rbind (cbind(ACE, hAC),
-		                 cbind(hAC, ACE)), dimnames = list(selVars, selVars), name = "expCovDZ")
+		expCovMZ, expCovDZ
 	)
 	model = mxModel(model, top) 
 	
@@ -406,9 +410,9 @@ umxSummaryACEv <- function(model, digits = 2, file = getOption("umx_auto_plot"),
 		std = FALSE
 		# message("Polite message: in next version, show= will be replaced with std=TRUE/FALSE/NULL")
 	}
-	report = match.arg(report)
-	commaSep = paste0(umx_set_separator(silent=TRUE), " ")
-	# depends on R2HTML::HTML
+	report   = match.arg(report)
+	commaSep = paste0(umx_set_separator(silent = TRUE), " ")
+	# Depends on R2HTML::HTML
 	if(typeof(model) == "list"){ # call self recursively
 		for(thisFit in model) {
 			message("Output for Model: ", thisFit$name)
@@ -423,7 +427,6 @@ umxSummaryACEv <- function(model, digits = 2, file = getOption("umx_auto_plot"),
 	A = mxEval(top.A, model) # Variances
 	C = mxEval(top.C, model)
 	E = mxEval(top.E, model)
-
 	if(std){
 		caption = paste0("Standardized parameter estimates from a ", dim(A)[2], "-factor Direct variance ACE model. ")
 		
